# GoodData.CN Helm Chart

- Maintained by: [GoodData](https://gooddata.com)
- [Documentation and API reference](https://www.gooddata.com/developers/cloud-native/doc/)
- Where to get help: the [GoodData Community forums](https://community.gooddata.com/), or the [GoodData Community Slack](https://www.gooddata.com/developers/#connect)

## What is GoodData.CN?

GoodData.CN is a cloud-native analytics service you can deploy next to your data. It comes as a deployable single packaged Kubernetes YAML manifest (helm chart) that is meant to be used for production purposes of GoodData.CN.

GoodData.CN gives you a headless analytics service you can fully manage and control programmatically. You can connect to and query our analytics engine similarly to any other database engine. Our query language MAQL resolves table joins and group-bys in real time.

GoodData enforces an analytics data model with shared definitions of metrics. The metrics are context-aware, so one definition supports multiple calculations (think aggregations and filters as named functions you can pass as arguments). That gives you governed self-service analytics: Business users can explore data while using the same definitions–even if they work with different slices of data.

Multi-tenant analytics is supported via the concept of analytics workspaces for different groups of users. You can inherit a workspace definition in another workspace with one API call.

You can integrate GoodData.CN with your data warehouse, user authentication system, version control system, alerting system, etc.

GoodData.CN includes:

- **Analytics Engine**: Connects directly to your data warehouse and translates the analytics queries from MAQL to SQL in real time.
- **Visual tools**: You can build dashboards and explore the data in a drag-and-drop interface. There is also a data modeler to manage the logical data model and the mapping to your data source.
- **Metadata Layer**: Describes and enforces data semantics and relations from the business perspective. The logical data model and definitions of all the calculations are stored here, together with the reports and dashboards.
- **API Layer**: Exposes all operations and metadata. The results from the Analytics Engine can be plugged in for further processing. Declarative APIs are available to support the life cycle of analytics development.
- GoodData.CN works with the **GoodData.UI** library. What you built, you can easily integrate with your application on the chart or dashboard level. [Learn more](https://sdk.gooddata.com/gooddata-ui/).

GoodData.CN works with:

- PostgreSQL
- AWS Redshift
- Snowflake
- Vertica

GoodData.CN can be deployed into:

- AWS
- MS Azure
- Google Cloud
- Any Kubernetes-compatible distribution

For more information about GoodData, please visit www.gooddata.com.

## Installation and Usage

[Learn how to use this helm chart and install GoodData.CN](https://www.gooddata.com/developers/cloud-native/doc/)

## License

GoodData.CN Helm chart is licensed under Apache 2.0.

The application installed by the Helm chart, GoodData.CN,  is a cloud-native analytics product available in three editions: GoodData.CN FREE Edition, GoodData.CN GROWTH Edition, and GoodData.CN ENTERPRISE Edition. You must enter into a commercial license agreement with GoodData in order to use GoodData.CN and receive a license key to do so.
For more information on licensing, please see [https://www.gooddata.com/developers/cloud-native/] and for documentation please see [https://www.gooddata.com/developers/cloud-native/doc/]. All usage of GoodData.CN is governed by the GoodData Privacy Policy available at [https://www.gooddata.com/privacy-policy/].

GoodData.CN may include or be accompanied by software provided by third parties, including software provided to you under an open source software (OSS) license, as indicated in the applicable commercial license for GoodData.CN. Such third-party software may have been modified by GoodData and/or may be subject to third-party license restrictions, which you must accept as a condition to using such software.  Please see [https://www.gooddata.com/legal/gooddata-cn-licenses] for details, including copyright notices, attributions, and third-party license terms. To the extent the license for any OSS requires GoodData to make available to you the source code (and/or any modifications), you may obtain a copy by sending a written request, with your name and address to: GoodData Corporation, 1 Post St, Ste. 400, San Francisco, CA, 94104, United States of America or legal@goodddata.com. All requests should clearly specify: Source Code Request, Attention: General Counsel. This offer to obtain a copy of the source code is valid for three years from the date you acquired GoodData.CN.
