{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "gooddata-cn.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "gooddata-cn.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "gooddata-cn.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Common labels
*/}}
{{- define "gooddata-cn.labels" -}}
helm.sh/chart: {{ include "gooddata-cn.chart" . }}
{{ include "gooddata-cn.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "gooddata-cn.selectorLabels" -}}
app.kubernetes.io/name: {{ include "gooddata-cn.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
app.kubernetes.io/component: {{ .component }}
{{- end -}}

{{/*
Create the name of the service account to use
*/}}
{{- define "gooddata-cn.serviceAccountName" -}}
{{- if .Values.serviceAccount.create -}}
    {{ default (include "gooddata-cn.fullname" .) .Values.serviceAccount.name }}
{{- else -}}
    {{ default "default" .Values.serviceAccount.name }}
{{- end -}}
{{- end -}}

{{/*
Format Public Authentication URL for optional Dex component
*/}}
{{- define "gooddata-cn.authPublicUrl" -}}
{{ printf "%s://%s%s" .Values.ingress.lbProtocol (default "localhost" .Values.dex.ingress.authHost) (empty .Values.ingress.lbPort | ternary "" (printf ":%s" (.Values.ingress.lbPort | toString))) }}
{{- end -}}

{{/*
Format one Ingress rule
The new format (>=1.19) for networking.k8s.io/v1 is:
- path: {{ $path }}
  pathType: ImplementationSpecific
  backend:
    service:
      name: {{ $serviceName }}
      port:
        number: {{ $portNumber }}

This template accepts (tuple $serviceName $portNumber $path $scope ) as an argument.
The serviceName is automatically prepended by the "gooddata-cn.fullname" template.
Example: {{ tuple "webservice" 8080 /api . | include "gooddata-cn.ingressRule" }}
*/}}
{{- define "gooddata-cn.ingressRule" -}}
{{- $service := index . 0 -}}
{{- $port := index . 1 -}}
{{- $path := index . 2 -}}
{{- $scope := index . 3 }}
{{- $serviceName := printf "%s-%s" (include "gooddata-cn.fullname" $scope ) $service }}
- path: {{ $path }}
  pathType: ImplementationSpecific
  backend:
    service:
      name: {{ $serviceName }}
      port:
        number: {{ $port }}
{{- end -}}

{{/*
Calls helm function tpl smart way. If the first argument is string, it is
rendered verbatim. If it is an object, it's piped through toYaml.
Example: {{ include "gooddata-cn.tpl" (tuple .Values.some.data . )}}
*/}}
{{- define "gooddata-cn.tpl" -}}
  {{- $value := index . 0 -}}
  {{- $scope := index . 1 -}}
  {{- if typeIs "string" $value -}}
      {{- tpl .value $scope }}
  {{- else }}
      {{- tpl ($value | toYaml) $scope }}
  {{- end }}
{{- end -}}