{{/*
Create PodMonitor for component
This template accepts (tuple $component $scope ) as an argument.
Example: {{ tuple "afmExecApi" . | include "gooddata-cn.podmonitor" }}
*/}}
{{- define "gooddata-cn.podmonitor" -}}
{{- $component := index . 0 -}}
{{- $scope := index . 1 }}
{{/*  Use with function to use .Values directly instead of index $scope "Values" */}}
{{- with $scope }}
{{/* Merge and overwrite values from .Values.podMonitor with .Values.component.podMonitor */}}
{{- $podMonitor := mustMergeOverwrite (mustDeepCopy .Values.podMonitor) (index .Values $component "podMonitor") }}

{{- if and ( .Capabilities.APIVersions.Has "monitoring.coreos.com/v1" ) $podMonitor.enabled -}}
apiVersion: monitoring.coreos.com/v1
kind: PodMonitor
metadata:
  {{/* I have to use kebabcase (!) because only lowercase chars are allowed */}}
  name: {{ include "gooddata-cn.fullname" . }}-{{ kebabcase $component }}
  labels:
    {{- include "gooddata-cn.labels" . | nindent 4 }}
    {{- with $podMonitor.additionalLabels }}
    {{- toYaml . | nindent 4 }}
    {{- end }}
spec:
  jobLabel: {{ .Release.Name }}
  namespaceSelector:
    matchNames:
      - {{ .Release.Namespace }}
  selector:
    matchLabels:
      {{- include "gooddata-cn.selectorLabels" . | nindent 6 }}
    matchExpressions:
      - key: prometheus.io/pod-monitor
        operator: NotIn
        values:
          - "false"
  podMetricsEndpoints:
    - port: {{ $podMonitor.port }}
      path: {{ $podMonitor.path }}
      interval: {{ $podMonitor.interval }}
      scrapeTimeout: {{ $podMonitor.scrapeTimeout }}
{{- end }}
{{- end -}}
{{- end }}
