{{- define "gooddata-cn.postgresHost" -}}
{{- if .Values.deployPostgresHA -}}
{{ .Release.Name }}-{{ index .Values "postgresql-ha" "nameOverride" | default "postgresql-ha" }}-pgpool
{{- else -}}
{{ .Values.service.postgres.host }}
{{- end -}}
{{- end -}}

{{- define "gooddata-cn.postgresPort" -}}
{{- if .Values.deployPostgresHA -}}
{{ .Values.pgpool.ports.postgresql }}
{{- else -}}
{{ .Values.service.postgres.port }}
{{- end -}}
{{- end -}}

{{- define "gooddata-cn.postgresUsername" -}}
{{- if .Values.deployPostgresHA -}}
{{ index .Values "postgresql-ha" "postgresql" "username" }}
{{- else -}}
{{ .Values.service.postgres.username }}
{{- end -}}
{{- end -}}

{{- /*
This section sets the secret for postgres connection in GoodData.CN chart and possibly
also for postgresql-ha chart itself.

In case we want to deploy postgres subchart the order of secret retrieval and its name is following:
1. value of "global.postgresql.existingSecret"
2. value of "postgresql-ha.postgres.existingSecret"
3. {{ .Release.Name }}-db-postgresql - this secret is populated from the chart values.yaml

In case we do not want to deploy postgres subchart:
1. value of "service.postgres.existingSecret"
2. {{ include "gooddata-cn.fullname" . }}-postgres-password - this secret populated from the chart values.yaml
*/}}

{{- define "gooddata-cn.postgresSecret" -}}
{{- $pgHAexistingSecret := index .Values "postgresql-ha" "postgresql" "existingSecret" -}}
{{- if .Values.deployPostgresHA -}}
{{- $global := default dict .Values.global -}}
{{- $postgresql := default dict $global.postgresql -}}
{{- $postgresql.existingSecret | default ($pgHAexistingSecret | default (printf "%s-db-postgresql" .Release.Name)) -}}
{{- else -}}
{{- .Values.service.postgres.existingSecret | default (printf "%s-postgres-password" (include "gooddata-cn.fullname" .)) -}}
{{- end -}}
{{- end -}}

{{- define "gooddata-cn.jdbcCommon" -}}
{{- if .Values.deployPostgresHA -}}
jdbc:postgresql://{{ .Release.Name }}-db-pgpool:{{ .Values.pgpool.ports.postgresql }}
{{- else -}}
jdbc:postgresql://{{ .Values.service.postgres.host }}:{{ .Values.service.postgres.port }}
{{- end -}}
{{- end -}}

{{- define "gooddata-cn.jdbcUrlMd" -}}
{{ include "gooddata-cn.jdbcCommon" . }}/{{ .Values.metadataApi.database.name }}?reWriteBatchedInserts=true
{{- end -}}

{{- define "gooddata-cn.jdbcUrlExecution" -}}
{{ include "gooddata-cn.jdbcCommon" . }}/{{ .Values.sqlExecutor.database.name }}
{{- end -}}

{{- define "gooddata-cn.jdbcUrlDex" -}}
{{ include "gooddata-cn.jdbcCommon" . }}/{{ .Values.dex.config.database.name }}
{{- end -}}
