{{/*
Create PrometheusRule for component
This template accepts (tuple $component $scope ) as an argument.
Example: {{ tuple "afmExecApi" . | include "gooddata-cn.prometheusrule" }}
*/}}
{{- define "gooddata-cn.prometheusrule" -}}
{{- $component := index . 0 -}}
{{- $scope := index . 1 }}
{{/*  Use with function to use .Values directly instead of index $scope "Values" */}}
{{- with $scope }}
{{/* Merge and overwrite values from .Values.prometheusRule with .Values.component.prometheusRule */}}
{{- $prometheusRule := mustMergeOverwrite (mustDeepCopy .Values.prometheusRule) (index .Values $component "prometheusRule") }}

{{- if and ( .Capabilities.APIVersions.Has "monitoring.coreos.com/v1" ) $prometheusRule.enabled -}}
apiVersion: monitoring.coreos.com/v1
kind: PrometheusRule
metadata:
  {{/* I have to use kebabcase (!) because only lowercase chars are allowed */}}
  name: {{ include "gooddata-cn.fullname" . }}-{{ kebabcase $component }}
  {{- if $prometheusRule.namespace }}
  namespace: {{ $prometheusRule.namespace }}
  {{- end }}
  labels:
    {{- include "gooddata-cn.labels" . | nindent 4 }}
    {{- with $prometheusRule.labels }}
    {{- toYaml . | nindent 4 }}
    {{- end }}
spec:
  {{- with $prometheusRule.rules }}
  groups:
  - name: {{ kebabcase $component }}-rules
    rules: {{- toYaml . | nindent 4 }}
  {{- end }}
{{- end }}
{{- end -}}
{{- end }}
