{{/*
Generate comma-separated list of host:port pairs.
The port is the same and it is prepended to given list of hosts in
a following manner:
values.yaml:
  hosts:
  - somehost
  - otherhost
  port: 1234

usage of this template:
  {{ tuple .Values.port .Values.hosts | include "gooddata-cn.redisHostsList" }}

output:
  somehost:1234,otherhost:1234
*/}}
{{- define "gooddata-cn.redisHostsList" -}}
{{ $port := index . 0 }}
{{- $local := dict "first" true -}}
{{- range $k, $v := index . 1 -}}{{- if not $local.first -}},{{- end -}}{{- $v -}}:{{- $port -}}{{- $_ := set $local "first" false -}}{{- end -}}
{{- end -}}

{{/*
Return the name of secret with Redis password. User-provided secret is preferred, defaults
to our Secret created by this helm chart.
*/}}
{{- define "gooddata-cn.redisSecret" -}}
{{- .Values.service.redis.existingSecret | default (printf "%s-redis-password" (include "gooddata-cn.fullname" .)) -}}
{{- end -}}

{{/*
Generate Env variables needed to connect to Redis, based on
given values.
When deployRedisHA=true, it sets following variables:
- SPRING_REDIS_SENTINEL_MASTER
- SPRING_REDIS_SENTINEL_NODES
It's used for accessing redis cluster deployed as a subchart,
using Sentinel method.

Wnen service.redis.clusterMode=true, it sets SPRING_REDIS_CLUSTER_NODES
to list of host:port tuples.
It sets single redis to SPRING_REDIS_HOST and SPRING_REDIS_PORT otherwise.
*/}}
{{- define "gooddata-cn.redisEnv" -}}
{{- if .Values.deployRedisHA }}
- name: SPRING_REDIS_SENTINEL_MASTER
  value: {{ .Values.redis.masterGroupName | quote }}
- name: SPRING_REDIS_SENTINEL_NODES
  value: "{{ .Release.Name }}-redis-ha:{{ .Values.sentinel.port }}"
{{- else }}
{{- if .Values.service.redis.clusterMode }}
- name: SPRING_REDIS_CLUSTER_NODES
  value: {{ tuple .Values.service.redis.port .Values.service.redis.hosts | include "gooddata-cn.redisHostsList" | quote }}
{{- else }}
{{- if gt (len .Values.service.redis.hosts) 1 }}
{{- fail "Multiple redis hosts defined in non-clustered mode." }}
{{- end }}
- name: SPRING_REDIS_HOST
  value: {{ index .Values.service.redis.hosts 0 | quote }}
- name: SPRING_REDIS_PORT
  value: {{ .Values.service.redis.port | quote }}
{{- end }}
{{- end }}
{{- if or .Values.service.redis.existingSecret .Values.service.redis.password }}
- name: SPRING_REDIS_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ include "gooddata-cn.redisSecret" . | quote }}
      key: redis-password
{{- end }}
{{- if .Values.service.redis.useSSL }}
- name: SPRING_REDIS_SSL
  value: {{ .Values.service.redis.useSSL | quote }}
{{- end }}
{{- end -}}
