{{/*
Liveness and readiness probes for springboot apps. Set context to given application.
*/}}
{{- define "gooddata-cn.probes" -}}
livenessProbe:
  httpGet:
    path: /actuator/health/liveness
    port: {{ .actuator.port }}
  initialDelaySeconds: 30
  periodSeconds: 10
  timeoutSeconds: 5
  failureThreshold: 5
readinessProbe:
  httpGet:
    path: /actuator/health/readiness
    port: {{ .actuator.port }}
  initialDelaySeconds: 30
  periodSeconds: 10
  timeoutSeconds: 10
  failureThreshold: 5
startupProbe:
  httpGet:
    path: /actuator/health/liveness
    port: {{ .actuator.port }}
  initialDelaySeconds: 30
  periodSeconds: 10
  timeoutSeconds: 5
  failureThreshold: 12
{{- end -}}

{{/*
ENV variables for Spring applications
 - SPRING_CONFIG_ADDITIONAL_LOCATION - to make the git properties available in banners
*/}}
{{- define "gooddata-cn.springEnv" -}}
- name: SPRING_MAIN_BANNER_MODE
  value: "off"
- name: SPRING_CONFIG_ADDITIONAL_LOCATION
  value: classpath:git.properties
- name: SPRING_ZIPKIN_ENABLED
  value: {{ .Values.monitoring.tracing.enabled | quote }}
- name: ZIPKIN_HOST
  value: {{ (printf "%s.%s" .Values.monitoring.tracing.zipkin.host .Values.monitoring.tracing.zipkin.namespace) | quote }}
- name: ZIPKIN_PORT
  value: {{ .Values.monitoring.tracing.zipkin.port | quote}}
{{- end -}}

{{/*
Pre-stop lifecycle hook for springboot apps via actuator. Set context to given application.
*/}}
{{- define "gooddata-cn.preStop" -}}
preStop:
  exec:
    command: ["sh", "-c", "/usr/bin/curl -Ssf -X POST localhost:{{ .actuator.port }}/actuator/shutdown && sleep 5"]
{{- end -}}
